Index: include/core/SkAdvancedTypefaceMetrics.h |
diff --git a/include/core/SkAdvancedTypefaceMetrics.h b/include/core/SkAdvancedTypefaceMetrics.h |
index 11926888f57b11a64effe47da9d7f32ac9995281..e75365ba31ca013b6b52e1e5250c157eb950a4af 100755 |
--- a/include/core/SkAdvancedTypefaceMetrics.h |
+++ b/include/core/SkAdvancedTypefaceMetrics.h |
@@ -35,21 +35,15 @@ public: |
kCFF_Font, |
kTrueType_Font, |
kOther_Font, |
+ kNotEmbeddable_Font |
}; |
// The type of the underlying font program. This field determines which |
// of the following fields are valid. If it is kOther_Font the per glyph |
// information will never be populated. |
FontType fType; |
- enum FontFlags { |
- kEmpty_FontFlag = 0x0, //!<No flags set |
- kMultiMaster_FontFlag = 0x1, //!<May be true for Type1 or CFF fonts. |
- kNotEmbeddable_FontFlag = 0x2, //!<May not be embedded. |
- kNotSubsettable_FontFlag = 0x4, //!<May not be subset. |
- }; |
- // Global font flags. |
- FontFlags fFlags; |
- |
+ // fMultiMaster may be true for Type1_Font or CFF_Font. |
+ bool fMultiMaster; |
uint16_t fLastGlyphID; // The last valid glyph ID in the font. |
uint16_t fEmSize; // The size of the em box (defines font units). |
@@ -35,21 +35,15 @@ public: |
}; |
// The type of the underlying font program. This field determines which |
- // of the following fields are valid. If it is kOther_Font the per glyph |
- // information will never be populated. |
+ // of the following fields are valid. If it is kOther_Font or |
+ // kNotEmbeddable_Font, the per glyph information will never be populated. |
FontType fType; |